==> feijoa-0.1.6.dev6.tar.gz: feijoa-0.1.6.dev6/feijoa/search/visitors.py <==
# MIT License
#
# Copyright (c) 2021-2022 Templin Konstantin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Different visitors module."""

import random

from feijoa.search.parameters import ParametersVisitor


class Randomizer(ParametersVisitor):
    """Randomizer for parameters visitor.

    Generate random values for specified parameters.

    Raises:
        AnyError: If anything bad happens.

    """

    def __init__(self, seed=0):
        self.random_generator = random.Random(x=seed)

    def visit_integer(self, p):
        return self.random_generator.randint(p.low, p.high)

    def visit_real(self, p):
        return (
            p.high - p.low
        ) * self.random_generator.random() + p.low

    def visit_categorical(self, p):
        return self.random_generator.choice(p.choices)

==> feijoa-0.1.7.tar.gz: feijoa-0.1.7/feijoa/search/visitors.py <==
# MIT License
#
# Copyright (c) 2021-2022 Templin Konstantin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Different visitors module."""

import random

from feijoa.search.parameters import ParametersVisitor


class Randomizer(ParametersVisitor):
    """
    Randomizer for parameters visitor.

    Generate random values for specified parameters.

    Raises:
        AnyError: If anything bad happens.

    """

    def __init__(self, seed=0):
        self.random_generator = random.Random(x=seed)

    def visit_integer(self, p):
        return self.random_generator.randint(p.low, p.high)

    def visit_real(self, p):
        return (
            p.high - p.low
        ) * self.random_generator.random() + p.low

    def visit_categorical(self, p):
        return self.random_generator.choice(p.choices)
